geom_typst() is a more powerful replacement for ggplot2::annotate() and
ggtext::geom_richtext() that renders a vector of raw Typst labels at data
positions. Each label is compiled independently with Typst. Parameter and
aesthetic names follow the conventions of ggplot2::geom_label().
Usage
geom_typst(
mapping = NULL,
data = NULL,
stat = "identity",
position = "identity",
...,
nudge_x = 0,
nudge_y = 0,
size.unit = "pt",
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)Arguments
- mapping
Set of aesthetic mappings created by
aes(). If specified andinherit.aes = TRUE(the default), it is combined with the default mapping at the top level of the plot. You must supplymappingif there is no plot mapping.- data
The data to be displayed in this layer. There are three options:
If
NULL, the default, the data is inherited from the plot data as specified in the call toggplot().A
data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. Seefortify()for which variables will be created.A
functionwill be called with a single argument, the plot data. The return value must be adata.frame, and will be used as the layer data. Afunctioncan be created from aformula(e.g.~ head(.x, 10)).- stat
The statistical transformation to use on the data for this layer. When using a
geom_*()function to construct a layer, thestatargument can be used to override the default coupling between geoms and stats. Thestatargument accepts the following:A
Statggproto subclass, for exampleStatCount.A string naming the stat. To give the stat as a string, strip the function name of the
stat_prefix. For example, to usestat_count(), give the stat as"count".For more information and other ways to specify the stat, see the layer stat documentation.
- position
A position adjustment to use on the data for this layer. This can be used in various ways, including to prevent overplotting and improving the display. The
positionargument accepts the following:The result of calling a position function, such as
position_jitter(). This method allows for passing extra arguments to the position.A string naming the position adjustment. To give the position as a string, strip the function name of the
position_prefix. For example, to useposition_jitter(), give the position as"jitter".For more information and other ways to specify the position, see the layer position documentation.
- ...
Other arguments passed on to
layer()'sparamsargument. These arguments broadly fall into one of 4 categories below. Notably, further arguments to thepositionargument, or aesthetics that are required can not be passed through.... Unknown arguments that are not part of the 4 categories below are ignored.Static aesthetics that are not mapped to a scale, but are at a fixed value and apply to the layer as a whole. For example,
colour = "red"orlinewidth = 3. The geom's documentation has an Aesthetics section that lists the available options. The 'required' aesthetics cannot be passed on to theparams. Please note that while passing unmapped aesthetics as vectors is technically possible, the order and required length is not guaranteed to be parallel to the input data.When constructing a layer using a
stat_*()function, the...argument can be used to pass on parameters to thegeompart of the layer. An example of this isstat_density(geom = "area", outline.type = "both"). The geom's documentation lists which parameters it can accept.Inversely, when constructing a layer using a
geom_*()function, the...argument can be used to pass on parameters to thestatpart of the layer. An example of this isgeom_area(stat = "density", adjust = 0.5). The stat's documentation lists which parameters it can accept.The
key_glyphargument oflayer()may also be passed on through.... This can be one of the functions described as key glyphs, to change the display of the layer in the legend.
- nudge_x, nudge_y
Horizontal and vertical nudge offsets. Supply these instead of
positionto shift labels after the default identity position.- size.unit
The unit of
size. Defaults to points ("pt"). Use"mm"for ggplot2-style text sizes.- na.rm
If
FALSE, the default, missing values are removed with a warning. IfTRUE, missing values are silently removed.- show.legend
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.FALSEnever includes, andTRUEalways includes. It can also be a named logical vector to finely select the aesthetics to display. To include legend keys for all levels, even when no data exists, useTRUE. IfNA, all levels are shown in legend, but unobserved levels are omitted.- inherit.aes
If
FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g.annotation_borders().
Aesthetics
geom_typst() understands the following aesthetics (required aesthetics are
in bold):
xylabelRaw Typst source code.labelcan be mapped inggplot2::aes()or supplied as a constant value, for examplegeom_typst(label = "Hello"), to render the same Typst label for every row in the layer.hjustvjustscalesizecolour(aliascolor)alphaface(aliasfontface)anglelineheightfamilymath_family
To learn more about these theme arguments, see annotate_typst(). If mapped
colour values are already literal colours such as "#1E66F5", add
ggplot2::scale_colour_identity() so ggplot2 treats them as colours instead
of discrete categories.
Examples
labels <- data.frame(
wt = c(2, 3.5, 4.5),
mpg = c(15, 30, 10),
label = c(
r"(*Toyota Corolla* 😂)",
r"(*Fiat 128*, $y = x$)",
r"(*_Maserati Bora_*)"
),
colour = c("blue", NA, "red")
)
ggplot(mtcars, aes(wt, mpg)) +
geom_point() +
geom_typst(
data = labels,
aes(wt, mpg, label = label, colour = colour),
scale = 1.1,
size = 14,
show.legend = FALSE
) +
scale_colour_identity() +
theme_minimal()
#> Warning: Removed 1 row containing missing values or values outside the scale range
#> (`geom_typst()`).